@@ -1,5 +1,5 @@
-;;;; $Id: command.lisp 218 2012-08-18 21:58:37Z ehuelsmann $
-;;;; $URL: svn://svn.common-lisp.net/project/cl-irc/svn/tags/0.9.1/command.lisp $
+;;;; $Id: command.lisp 238 2013-01-13 18:50:37Z ehuelsmann $
+;;;; $URL: file:///project/cl-irc/svn/tags/0.9.2/command.lisp $
 
 ;;;; See LICENSE for licensing information.
 
@@ -9,7 +9,7 @@
 (defgeneric nick (connection new-nickname))
 (defgeneric user- (connection username mode &optional realname))
 (defgeneric oper (connection name password))
-(defgeneric mode (connection nickname mode))
+(defgeneric mode (connection nickname &optional mode))
 (defgeneric op (connection channel nickname))
 (defgeneric deop (connection channel nickname))
 (defgeneric voice (connection channel user))
@@ -103,7 +103,7 @@ registered."
 (defmethod oper ((connection connection) (name string) (password string))
   (send-irc-message connection :oper name password))
 
-(defmethod mode ((connection connection) (nickname string) (mode string))
+(defmethod mode ((connection connection) (nickname string) &optional mode)
   (send-irc-message connection :mode nickname mode))
 
 ;; utility functions not part of the RFCs
@@ -293,16 +293,10 @@ connect to.  `connection-security' determines which port number is found.
                                        (usocket:socket-stream socket))
                    (usocket:socket-stream socket)))
          (connection (make-connection :connection-type connection-type
-                                      :socket socket
                                       :network-stream stream
                                       :client-stream logging-stream
-                                      :server-name server))
-         (user (make-user connection
-                          :nickname nickname
-                          :username username
-                          :realname realname)))
+                                      :server-name server)))
     #+sbcl (setf (sb-bsd-sockets::sockopt-keep-alive (usocket:socket socket)) t)
-    (setf (user connection) user)
     (unless (null password)
       (pass connection password))
     (nick connection nickname)
@@ -557,7 +551,6 @@ for `connection'."))
             (make-dcc-chat-connection
              :irc-connection irc-connection
              :remote-user (find-user irc-connection (source message))
-             :socket socket
              :network-stream (usocket:socket-stream socket))))))))
 
 (defmethod dcc-request-accept ((message dcc-ctcp-dcc-chat-request-message))
