@@ -1,5 +1,5 @@
-;;;; $Id: event.lisp 204 2007-04-30 07:56:05Z ehuelsmann $
-;;;; $URL: svn://svn.common-lisp.net/project/cl-irc/svn/tags/0.9.1/event.lisp $
+;;;; $Id: event.lisp 243 2013-07-01 20:16:35Z jdanjou $
+;;;; $URL: file:///project/cl-irc/svn/tags/0.9.2/event.lisp $
 
 ;;;; See LICENSE for licensing information.
 
@@ -141,6 +141,19 @@ objects in sync."))
               (username user) username
               (hostname user) hostname)))))
 
+(defmethod default-hook ((message irc-rpl_welcome-message))
+  (with-slots
+        (connection host user arguments)
+      message
+    (destructuring-bind
+          (nickname welcome-message)
+        arguments
+      (setf (user connection)
+            (make-user connection
+                       :nickname nickname
+                       :hostname host
+                       :username user)))))
+
 (defmethod default-hook ((message irc-rpl_list-message))
   (destructuring-bind
       (channel count topic)
@@ -181,8 +194,8 @@ objects in sync."))
                                                                 nickname))))
             (unless (equal user (user connection))
               (add-user connection user)
-              (add-user channel user)
-              (set-mode channel 'namreply-in-progress user))
+              (add-user channel user))
+            (set-mode channel 'namreply-in-progress user)
             (let* ((mode-char (getf (nick-prefixes connection)
                                     (elt nickname 0)))
                    (mode-name (when mode-char
@@ -266,20 +279,10 @@ objects in sync."))
     (destructuring-bind
         (target channel &rest mode-arguments)
         arguments
-    (let* ((channel (find-channel connection channel))
-           (mode-changes
-            (when channel
-              (parse-mode-arguments connection channel mode-arguments
-                                    :server-p (user connection)))))
-      (dolist (change mode-changes)
-        (destructuring-bind
-            (op mode-name value)
-            change
-          (unless (has-mode-p channel mode-name)
-            (add-mode target mode-name
-                      (make-mode connection channel mode-name)))
-          (funcall (if (char= #\+ op) #'set-mode #'unset-mode)
-                   channel mode-name value)))))))
+      (let ((channel (find-channel connection channel)))
+        (when channel
+          (apply-mode-changes connection channel
+                              mode-arguments (user connection)))))))
 
 (defmethod default-hook ((message irc-mode-message))
   (destructuring-bind
@@ -287,20 +290,9 @@ objects in sync."))
       (arguments message)
     (let* ((connection (connection message))
            (target (or (find-channel connection target)
-                       (find-user connection target)))
-           (mode-changes
-            (when target
-              (parse-mode-arguments connection target arguments
-                                     :server-p (user connection)))))
-      (dolist (change mode-changes)
-        (destructuring-bind
-            (op mode-name value)
-            change
-          (unless (has-mode-p target mode-name)
-            (add-mode target mode-name
-                      (make-mode connection target mode-name)))
-          (funcall (if (char= #\+ op) #'set-mode #'unset-mode)
-                   target mode-name value))))))
+                       (find-user connection target))))
+      (when target
+        (apply-mode-changes connection target arguments (user connection))))))
 
 (defmethod default-hook ((message irc-nick-message))
   (with-slots
