@@ -1,5 +1,5 @@
-;;;; $Id: protocol.lisp 228 2012-09-23 16:20:09Z ehuelsmann $
-;;;; $URL: svn://svn.common-lisp.net/project/cl-irc/svn/tags/0.9.1/protocol.lisp $
+;;;; $Id: protocol.lisp 245 2015-09-06 13:16:49Z ehuelsmann $
+;;;; $URL: file:///project/cl-irc/svn/tags/0.9.2/protocol.lisp $
 
 ;;;; See LICENSE for licensing information.
 
@@ -122,10 +122,6 @@ user class.")))
     :initarg :server-port
     :accessor server-port
     :initform *default-irc-server-port*)
-   (socket
-    :initarg :socket
-    :reader socket
-    :documentation "Slot to store socket (for internal use only).")
    (network-stream
     :initarg :network-stream
     :accessor network-stream
@@ -199,6 +195,7 @@ connection.")
 (defgeneric send-irc-message (connection command &rest arguments))
 (defgeneric get-hooks (connection class))
 (defgeneric add-hook (connection class hook))
+(defgeneric append-hook (connection class hook))
 (defgeneric remove-hook (connection class hook))
 (defgeneric remove-hooks (connection class))
 (defgeneric remove-all-hooks (connection))
@@ -211,7 +208,6 @@ connection.")
                              (password nil)
                              (server-name "")
                              (server-port nil)
-                             (socket nil)
                              (network-stream nil)
                              (outgoing-external-format *default-outgoing-external-format*)
                              (client-stream t)
@@ -225,7 +221,6 @@ connection.")
                                    :password password
                                    :server-name server-name
                                    :server-port server-port
-                                   :socket socket
                                    :network-stream network-stream
                                    :output-stream output-stream
                                    :client-stream client-stream)))
@@ -246,6 +241,7 @@ connection.")
                      irc-rpl_topic-message
                      irc-rpl_namreply-message
                      irc-rpl_endofnames-message
+                     irc-rpl_welcome-message
                      irc-ping-message
                      irc-join-message
                      irc-topic-message
@@ -337,7 +333,7 @@ this function is DEPRECATED."
   (declare (ignorable process))
     #+cmu (mp:destroy-process process)
     #+allegro (mp:process-kill process)
-    #+sb-thread (sb-thread:destroy-thread process)
+    #+sb-thread (sb-thread:terminate-thread process)
     #+lispworks (mp:process-kill process)
     #+openmcl (ccl:process-kill process)
     #+armedbear (threads:destroy-thread process))
@@ -383,6 +379,11 @@ server, via the `connection'."
   (setf (gethash class (hooks connection))
         (pushnew hook (gethash class (hooks connection)))))
 
+(defmethod append-hook (connection class hook)
+  "Append `hook' to `class'."
+  (setf (gethash class (hooks connection))
+        (append (gethash class (hooks connection)) (list hook))))
+
 (defmethod remove-hook ((connection connection) class hook)
   "Remove `hook' from `class'."
   (setf (gethash class (hooks connection))
@@ -454,11 +455,6 @@ a lost connection is detected.")
     :accessor remote-user
     :documentation "The user at the other end of this connection.  The
 user at this end can be reached via your normal connection object.")
-   (socket
-    :initarg :socket
-    :accessor socket
-    :initform nil
-    :documentation "Socket used to do the remote client.")
    (network-stream
     :initarg :network-stream
     :accessor network-stream)
@@ -547,7 +543,6 @@ of the network pipe.")
                                       (client-stream nil)
                                       (irc-connection nil)
                                       (close-on-main t)
-                                      (socket nil)
                                       (network-stream nil)
                                       (outgoing-external-format *default-outgoing-external-format*)
                                       (hooks nil))
@@ -562,7 +557,6 @@ of the network pipe.")
                                     :output-stream output-stream
                                     :irc-connection irc-connection
                                     :close-on-main close-on-main
-                                    :socket socket
                                     :network-stream network-stream)))
     (dolist (hook hooks)
       (add-hook connection (car hook) (cdar hook)))
